/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter.daten.container;

import de.bsvrz.sys.funclib.bitctrl.interpreter.Operator;

/**
 * Definition der Operatoren und Memberfunktionen zur Arbeit mit Uda-Containern.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public final class ContainerOperators {
	/**
	 * Konstruktor für ein Feld-Objekt.
	 */
	public static final Operator FELD_KONSTRUKTOR = Operator.getOperator("Feld");

	/**
	 * Konstruktor für ein Listenobjekt.
	 */
	public static final Operator LISTEN_KONSTRUKTOR = Operator.getOperator("Liste");

	/**
	 * Konstruktor für ein Schlüsselmengenobjekt.
	 */
	public static final Operator SCHLUSSELMENGEN_KONSTRUKTOR = Operator.getOperator("Schlüsselmenge");

	/**
	 * liefert die Anzahl der Elemente in einem Container.
	 */
	public static final Operator ANZAHL = Operator.getOperator("anzahl");

	/**
	 * fügt ein Element vor einem anderen in einen Container ein.
	 */
	public static final Operator EINFUEGEN = Operator.getOperator("einfügen");

	/**
	 * fügt ein Element nach einem anderen in einen Container ein.
	 */
	public static final Operator ANHAENGEN = Operator.getOperator("anhängen");

	/**
	 * liefert ein Element des Containers.
	 */
	public static final Operator ELEMENT = Operator.getOperator("element");

	/**
	 * entfernt ein Element aus dem Container.
	 */
	public static final Operator LOESCHEN = Operator.getOperator("löschen");

	/**
	 * erzeugt einen Iterator, der vor das erste Element eines Containers
	 * positioniert ist.
	 */
	public static final Operator ANFANG = Operator.getOperator("anfang");

	/**
	 * erzeugt einen Iterator, der auf das erste Element eines Containers
	 * positioniert ist.
	 */
	public static final Operator ERSTES = Operator.getOperator("erstes");

	/**
	 * erzeugt einen Iterator, der auf ein angegebenes Element eines Containers
	 * positioniert ist.
	 */
	public static final Operator ITERATOR = Operator.getOperator("iterator");

	/**
	 * erzeugt einen Iterator, der auf das letzte Element eines Containers
	 * positioniert ist.
	 */
	public static final Operator LETZTES = Operator.getOperator("letztes");

	/**
	 * erzeugt einen Iterator, der hinter das letzte Element eines Containers
	 * positioniert ist.
	 */
	public static final Operator SCHLUSS = Operator.getOperator("schluss");

	/**
	 * liefert den Container, der einem Iterator zu Grunde liegt.
	 */
	public static final Operator CONTAINER = Operator.getOperator("container");

	/**
	 * liefert einen Iterator aus einem Iterator, der auf das Vorgängerelement
	 * des Elementes positioniert ist, auf das der zu Grunde liegende Iterator
	 * verweist.
	 */
	public static final Operator VORGAENGER = Operator.getOperator("vorgänger");

	/**
	 * liefert einen Iterator aus einem Iterator, der auf das Nachfolgerelement
	 * des Elementes positioniert ist, auf das der zu Grunde liegende Iterator
	 * verweist.
	 */
	public static final Operator NACHFOLGER = Operator.getOperator("nachfolger");

	/**
	 * bewegt einen Iterator auf die vorhergehende Position.
	 */
	public static final Operator ZURUECK = Operator.getOperator("zurück");

	/**
	 * bewegt einen Iterator auf die nachfolgende Position.
	 */
	public static final Operator WEITER = Operator.getOperator("weiter");

	/**
	 * prüft, ob ein Iterator auf ein gültiges Element verweist.
	 */
	public static final Operator INNERHALB = Operator.getOperator("innerhalb");

	/**
	 * liefert den Schlüssel, der einem Element aus einer Schlüsselmenge
	 * zugeordnet ist.
	 */
	public static final Operator SCHLUESSEL = Operator.getOperator("schlüssel");

	/**
	 * die Liste der verfügbaren Operatoren.
	 */
	public static final Operator[] OPERATOREN = { ContainerOperators.FELD_KONSTRUKTOR,
			ContainerOperators.LISTEN_KONSTRUKTOR, ContainerOperators.SCHLUSSELMENGEN_KONSTRUKTOR,
			ContainerOperators.ANZAHL, ContainerOperators.EINFUEGEN, ContainerOperators.ANHAENGEN,
			ContainerOperators.ELEMENT, ContainerOperators.LOESCHEN, ContainerOperators.ANFANG,
			ContainerOperators.ERSTES, ContainerOperators.ITERATOR, ContainerOperators.LETZTES,
			ContainerOperators.SCHLUSS, ContainerOperators.CONTAINER, ContainerOperators.VORGAENGER,
			ContainerOperators.NACHFOLGER, ContainerOperators.WEITER, ContainerOperators.ZURUECK,
			ContainerOperators.INNERHALB, ContainerOperators.SCHLUESSEL };

	/** privater Konstruktor für Utility-Klasse. */
	private ContainerOperators() {
		super();
	}

}
