/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter.daten.container;

import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

import de.bsvrz.ibv.uda.interpreter.daten.fehler.ArgumentFehler;
import de.bsvrz.ibv.uda.interpreter.daten.fehler.ContainerZugriffsFehler;

/**
 * Testklasse zur Prüfung der Funktionen der UdaContainer-Klasse Liste.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public class ListeTest {

	/**
	 * die Liste mit der die Tests ausgeführt werden.
	 */
	private Liste testListe;

	/**
	 * füllt die Liste mit Daten.
	 */
	@Before
	public void setupTestListe() {
		testListe = new Liste();
		testListe.anhaengen(-1, 1);
		testListe.anhaengen(-1, 2);
		testListe.anhaengen(-1, 3);
		testListe.anhaengen(-1, 4);
	}

	/**
	 * testet den Konstruktor ohne Argumente.
	 */
	@Test
	public void testListe() {
		Assert.assertEquals(0, new Liste().getGroesse());
		Assert.assertEquals(0, new Liste(null).getGroesse());
	}

	/**
	 * testet den Konstruktor mit Angabe eines initialen Containers.
	 */
	@Test
	public void testListeUdaContainer() {
		final Liste liste = new Liste(testListe);
		Assert.assertEquals(4, liste.getGroesse());
		Assert.assertEquals(1, ((Number) liste.getContainerElement(1)).intValue());
		Assert.assertEquals(2, ((Number) liste.getContainerElement(2)).intValue());
		Assert.assertEquals(3, ((Number) liste.getContainerElement(3)).intValue());
		Assert.assertEquals(4, ((Number) liste.getContainerElement(4)).intValue());
	}

	/**
	 * testet die Einfügefunktion für eine Liste.
	 */
	@Test
	public void testEinfuegenIndex() {
		Liste liste = new Liste(testListe);
		liste.einfuegen(1, 999);
		Assert.assertEquals("{999,1,2,3,4}", liste.toString());

		liste = new Liste(testListe);
		liste.einfuegen(2, 999);
		Assert.assertEquals("{1,999,2,3,4}", liste.toString());

		liste = new Liste(testListe);
		liste.einfuegen(3, 999);
		Assert.assertEquals("{1,2,999,3,4}", liste.toString());

		liste = new Liste(testListe);
		liste.einfuegen(4, 999);
		Assert.assertEquals("{1,2,3,999,4}", liste.toString());

		liste = new Liste(testListe);
		liste.einfuegen(5, 999);
		Assert.assertEquals("{1,2,3,4,999}", liste.toString());

		liste = new Liste(testListe);
		liste.einfuegen(6, 999);
		Assert.assertEquals("{1,2,3,4,999}", liste.toString());

		liste = new Liste(testListe);
		liste.einfuegen(150, 999);
		Assert.assertEquals("{1,2,3,4,999}", liste.toString());

		liste = new Liste(testListe);
		liste.einfuegen(0, 999);
		Assert.assertEquals("{1,2,3,4,999}", liste.toString());

		liste = new Liste(testListe);
		liste.einfuegen(-1, 999);
		Assert.assertEquals("{1,2,3,999,4}", liste.toString());

		liste = new Liste(testListe);
		liste.einfuegen(-2, 999);
		Assert.assertEquals("{1,2,999,3,4}", liste.toString());

		liste = new Liste(testListe);
		liste.einfuegen(-3, 999);
		Assert.assertEquals("{1,999,2,3,4}", liste.toString());

		liste = new Liste(testListe);
		liste.einfuegen(-4, 999);
		Assert.assertEquals("{999,1,2,3,4}", liste.toString());

		liste = new Liste(testListe);
		liste.einfuegen(-5, 999);
		Assert.assertEquals("{999,1,2,3,4}", liste.toString());

		liste = new Liste(testListe);
		liste.einfuegen(-6, 999);
		Assert.assertEquals("{999,1,2,3,4}", liste.toString());

		liste = new Liste(testListe);
		liste.einfuegen(-150, 999);
		Assert.assertEquals("{999,1,2,3,4}", liste.toString());
	}

	/**
	 * testet die Einfügefunktion über eine Schlüssel.
	 */
	@Test
	public void testElementEinfuegenSchluessel() {
		try {
			testListe.einfuegen("Heinz", 999);
			Assert.fail("Einfügen per Schlüssel möglich");
		} catch (final ArgumentFehler e) {
			// in ein Liste kann nicht per Schlüssel eingefügt werden
		}
		try {
			testListe.einfuegen("1", 999);
			Assert.fail("Einfügen per Schlüssel möglich");
		} catch (final ArgumentFehler e) {
			// in ein Liste kann nicht per Schlüssel eingefügt werden
		}
		try {
			testListe.einfuegen("", 999);
			Assert.fail("Einfügen per Schlüssel möglich");
		} catch (final ArgumentFehler e) {
			// in ein Liste kann nicht per Schlüssel eingefügt werden
		}
		try {
			testListe.einfuegen(null, 999);
			Assert.fail("Einfügen per Schlüssel möglich");
		} catch (final ArgumentFehler e) {
			// in ein Liste kann nicht per Schlüssel eingefügt werden
		}
	}

	/**
	 * testet die Anhängefunktion für eine Liste.
	 */
	@Test
	public void testAnhaengenIndex() {
		Liste liste = new Liste(testListe);
		liste.anhaengen(1, 999);
		Assert.assertEquals("{1,999,2,3,4}", liste.toString());

		liste = new Liste(testListe);
		liste.anhaengen(2, 999);
		Assert.assertEquals("{1,2,999,3,4}", liste.toString());

		liste = new Liste(testListe);
		liste.anhaengen(3, 999);
		Assert.assertEquals("{1,2,3,999,4}", liste.toString());

		liste = new Liste(testListe);
		liste.anhaengen(4, 999);
		Assert.assertEquals("{1,2,3,4,999}", liste.toString());

		liste = new Liste(testListe);
		liste.anhaengen(5, 999);
		Assert.assertEquals("{1,2,3,4,999}", liste.toString());

		liste = new Liste(testListe);
		liste.anhaengen(6, 999);
		Assert.assertEquals("{1,2,3,4,999}", liste.toString());

		liste = new Liste(testListe);
		liste.anhaengen(150, 999);
		Assert.assertEquals("{1,2,3,4,999}", liste.toString());

		liste = new Liste(testListe);
		liste.anhaengen(0, 999);
		Assert.assertEquals("{999,1,2,3,4}", liste.toString());

		liste = new Liste(testListe);
		liste.anhaengen(-1, 999);
		Assert.assertEquals("{1,2,3,4,999}", liste.toString());

		liste = new Liste(testListe);
		liste.anhaengen(-2, 999);
		Assert.assertEquals("{1,2,3,999,4}", liste.toString());

		liste = new Liste(testListe);
		liste.anhaengen(-3, 999);
		Assert.assertEquals("{1,2,999,3,4}", liste.toString());

		liste = new Liste(testListe);
		liste.anhaengen(-4, 999);
		Assert.assertEquals("{1,999,2,3,4}", liste.toString());

		liste = new Liste(testListe);
		liste.anhaengen(-5, 999);
		Assert.assertEquals("{999,1,2,3,4}", liste.toString());

		liste = new Liste(testListe);
		liste.anhaengen(-6, 999);
		Assert.assertEquals("{999,1,2,3,4}", liste.toString());

		liste = new Liste(testListe);
		liste.anhaengen(-150, 999);
		Assert.assertEquals("{999,1,2,3,4}", liste.toString());
	}

	/**
	 * testet das Löschen eines Elements über den Containerindex.
	 */
	@Test
	public void testLoeschenIndex() {
		Liste liste = new Liste(testListe);
		liste.loeschen(1);
		Assert.assertEquals("{2,3,4}", liste.toString());

		liste = new Liste(testListe);
		liste.loeschen(2);
		Assert.assertEquals("{1,3,4}", liste.toString());

		liste = new Liste(testListe);
		liste.loeschen(3);
		Assert.assertEquals("{1,2,4}", liste.toString());

		liste = new Liste(testListe);
		liste.loeschen(4);
		Assert.assertEquals("{1,2,3}", liste.toString());

		liste = new Liste(testListe);
		Assert.assertTrue(liste.loeschen(5) instanceof ContainerZugriffsFehler);

		liste = new Liste(testListe);
		Assert.assertTrue(liste.loeschen(6) instanceof ContainerZugriffsFehler);

		liste = new Liste(testListe);
		Assert.assertTrue(liste.loeschen(150) instanceof ContainerZugriffsFehler);

		liste = new Liste(testListe);
		Assert.assertTrue(liste.loeschen(0) instanceof ContainerZugriffsFehler);

		liste = new Liste(testListe);
		liste.loeschen(-1);
		Assert.assertEquals("{1,2,3}", liste.toString());

		liste = new Liste(testListe);
		liste.loeschen(-2);
		Assert.assertEquals("{1,2,4}", liste.toString());

		liste = new Liste(testListe);
		liste.loeschen(-3);
		Assert.assertEquals("{1,3,4}", liste.toString());

		liste = new Liste(testListe);
		liste.loeschen(-4);
		Assert.assertEquals("{2,3,4}", liste.toString());

		liste = new Liste(testListe);
		Assert.assertTrue(liste.loeschen(-5) instanceof ContainerZugriffsFehler);

		liste = new Liste(testListe);
		Assert.assertTrue(liste.loeschen(-6) instanceof ContainerZugriffsFehler);

		liste = new Liste(testListe);
		Assert.assertTrue(liste.loeschen(-150) instanceof ContainerZugriffsFehler);
	}

	/**
	 * testet das Löschen eines Elements über einen Schlüssel.
	 */
	@Test
	public void testElementLoeschenString() {
		try {
			testListe.loeschen("Heinz");
			Assert.fail("Löschen per Schlüssel möglich");
		} catch (final ArgumentFehler e) {
			// in ein Liste kann nicht per Schlüssel gelöscht werden
		}
		try {
			testListe.loeschen("1");
			Assert.fail("Löschen per Schlüssel möglich");
		} catch (final ArgumentFehler e) {
			// in ein Liste kann nicht per Schlüssel eingefügt werden
		}
		try {
			testListe.loeschen("");
			Assert.fail("Löschen per Schlüssel möglich");
		} catch (final ArgumentFehler e) {
			// in ein Liste kann nicht per Schlüssel eingefügt werden
		}
		try {
			testListe.loeschen(null);
			Assert.fail("Löschen per Schlüssel möglich");
		} catch (final ArgumentFehler e) {
			// in ein Liste kann nicht per Schlüssel eingefügt werden
		}
	}

	/**
	 * testet das Auslesen eines Elements über einen Index.
	 */
	@Test
	public void testGetContainerElement() {
		Assert.assertEquals(1, ((Number) testListe.getContainerElement(1)).intValue());
		Assert.assertEquals(2, ((Number) testListe.getContainerElement(2)).intValue());
		Assert.assertEquals(3, ((Number) testListe.getContainerElement(3)).intValue());
		Assert.assertEquals(4, ((Number) testListe.getContainerElement(4)).intValue());
		Assert.assertEquals(4, ((Number) testListe.getContainerElement(-1)).intValue());
		Assert.assertEquals(3, ((Number) testListe.getContainerElement(-2)).intValue());
		Assert.assertEquals(2, ((Number) testListe.getContainerElement(-3)).intValue());
		Assert.assertEquals(1, ((Number) testListe.getContainerElement(-4)).intValue());

		final int[] invalidIdx = new int[] { 0, 5, -5, 6, -6, 150, -150 };

		for (final int idx : invalidIdx) {
			Assert.assertTrue(testListe.getContainerElement(idx) instanceof ContainerZugriffsFehler);
		}
	}

	/**
	 * testet das Setzen eines Elements über den Containerindex.
	 */
	@Test
	public void testSetContainerElement() {
		Liste liste = new Liste(testListe);
		liste.setContainerElement(1, 999);
		Assert.assertEquals("{999,2,3,4}", liste.toString());

		liste = new Liste(testListe);
		liste.setContainerElement(2, 999);
		Assert.assertEquals("{1,999,3,4}", liste.toString());

		liste = new Liste(testListe);
		liste.setContainerElement(3, 999);
		Assert.assertEquals("{1,2,999,4}", liste.toString());

		liste = new Liste(testListe);
		liste.setContainerElement(4, 999);
		Assert.assertEquals("{1,2,3,999}", liste.toString());

		liste = new Liste(testListe);
		liste.setContainerElement(5, 999);
		Assert.assertEquals("{1,2,3,4,999}", liste.toString());

		liste = new Liste(testListe);
		try {
			liste.setContainerElement(6, 999);
			Assert.fail("Schreiben mit ungültigem Index möglich");
		} catch (final ContainerZugriffsFehler e) {
			// Schreiben korrekt abgelehnt
		}

		liste = new Liste(testListe);
		try {
			liste.setContainerElement(0, 999);
			Assert.fail("Schreiben mit ungültigem Index möglich");
		} catch (final ContainerZugriffsFehler e) {
			// Schreiben korrekt abgelehnt
		}

		liste = new Liste(testListe);
		liste.setContainerElement(-1, 999);
		Assert.assertEquals("{1,2,3,999}", liste.toString());

		liste = new Liste(testListe);
		liste.setContainerElement(-2, 999);
		Assert.assertEquals("{1,2,999,4}", liste.toString());

		liste = new Liste(testListe);
		liste.setContainerElement(-3, 999);
		Assert.assertEquals("{1,999,3,4}", liste.toString());

		liste = new Liste(testListe);
		liste.setContainerElement(-4, 999);
		Assert.assertEquals("{999,2,3,4}", liste.toString());

		liste = new Liste(testListe);
		try {
			liste.setContainerElement(-6, 999);
			Assert.fail("Schreiben mit ungültigem Index möglich");
		} catch (final ContainerZugriffsFehler e) {
			// Schreiben korrekt abgelehnt
		}

		liste = new Liste(testListe);
		try {
			liste.setContainerElement(-150, 999);
			Assert.fail("Schreiben mit ungültigem Index möglich");
		} catch (final ContainerZugriffsFehler e) {
			// Schreiben korrekt abgelehnt
		}

	}

	/**
	 * testet die Ausgabe eines Containers als Zeichenkette.
	 */
	@Test
	public void testToString() {
		Assert.assertEquals("{1,2,3,4}", testListe.toString());
	}
}
