/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.uda.data;

/**
 * Definition von Konstanten in UDA für die Kommunikation mit dem
 * Datenverteiler.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public final class UDA {
	/**
	 * die PID für den Datenverteiler-Typ UdaModul.
	 */
	public static final String TYP_MODUL = "typ.udaModul";

	/**
	 * die PID für den Datenverteiler-Typ UdaSkript.
	 */
	public static final String TYP_SKRIPT = "typ.udaSkript";

	/**
	 * die PID für den Datenverteiler-Typ UdaSkriptlauf.
	 */
	public static final String TYP_LAUF = "typ.udaSkriptLauf";

	/**
	 * der Name der Menge für Skripte innerhalb eines UdaModuls.
	 */
	public static final String MODUL_MENGE_SKRIPTE = "Skripte";

	/**
	 * der Name der Menge für Skriptläufe innerhalb eines UdaModuls.
	 */
	public static final String MODUL_MENGE_LAEUFE = "SkriptLäufe";

	/**
	 * die PID der Attributgruppe für die Veröffentlichung des öffentlichen
	 * Schlüssels für die Passwortverschlüsselung.
	 */
	public static final String MODUL_ATG_KEY = "atg.udaModulKey";

	/**
	 * die PID der Attributgruppe zur Darstellung der Daten eines Skripts.
	 */
	public static final String SKRIPT_ATG_SKRIPT = "atg.udaSkript";

	/**
	 * die PID der Attributgruppe zur Darstellung der Daten eines Skriptlaufs.
	 */
	public static final String LAUF_ATG_LAUF = "atg.udaSkriptLauf";

	/**
	 * die PID der Attributgruppe zur Darstellung des aktuellen
	 * Ausführungszustandes eines Skriptlaufs.
	 */
	public static final String LAUF_ATG_LAUF_ZUSTAND = "atg.udaSkriptLaufStatus";

	/**
	 * die PID der Attributgruppe zur Darstellung der Ausgabe-Logdaten eines
	 * DavProtokolls bei der Ausführung eines Skriptslaufs.
	 */
	public static final String LAUF_ATG_LAUF_LOGGER = "atg.udaSkriptLaufLogger";

	/**
	 * die PID der Attributgruppe zur Darstellung der Ergebnisse eines
	 * Skriptlaufs.
	 */
	public static final String LAUF_ATG_LAUF_ERGEBNIS = "atg.udaSkriptLaufErgebnis";

	/**
	 * die PID der Attributgruppe zur Übertragung einer Ausführungsanforderung
	 * an einen Skriptlauf.
	 */
	public static final String LAUF_ATG_LAUF_KOMMANDO = "atg.udaSkriptLaufKommando";

	/**
	 * die PID des Aspekts zur Vorgabe von Uda-Daten.
	 */
	public static final String ASP_VORGABE = "asp.udaVorgabe";

	/**
	 * die PID des Aspekts zur Veröffentlichung des Ist-Zustandes von Uda-Daten.
	 */
	public static final String ASP_IST = "asp.udaIst";

	/**
	 * die PID des Aspekts zur Versendung einer Uda-Anforderung.
	 */
	public static final String ASP_ANFORDERUNG = "asp.udaAnforderung";

	/**
	 * die PID des Aspekts zur Versendung einer Anwtwort auf eine
	 * Uda-Anforderung.
	 */
	public static final String ASP_ANTWORT = "asp.udaAntwort";

	/**
	 * Attribut für den Namen eines Skripts.
	 */
	public static final String SKRIPT_ATT_NAME = "Name";

	/**
	 * Attribut für die Beschreibung eines Skripts.
	 */
	public static final String SKRIPT_ATT_BESCHREIBUNG = "Beschreibung";

	/**
	 * Attribut für die Beschreibung des Erstellungsdatums eines Skripts.
	 */
	public static final String SKRIPT_ATT_ERSTELLT_AM = "ErstelltAm";

	/**
	 * Attribut für den Namen des Erstellers eines Skripts.
	 */
	public static final String SKRIPT_ATT_ERSTELLT_DURCH = "ErstelltDurch";

	/**
	 * Attribut für den Bearbeitungszustand eines Skripts.
	 */
	public static final String SKRIPT_ATT_ZUSTAND = "Zustand";

	/**
	 * Attribut für die Versionshistorie eines Skripts.
	 */
	public static final String SKRIPT_ATT_VERSIONSHISTORIE = "Versionshistorie";

	/**
	 * Attribut für die Änderungsdatum in einem Eintrag der Versionshistorie
	 * eines Skripts.
	 */
	public static final String ATL_HISTORIE_ATT_AENDERUNGSDATUM = "Änderungsdatum";

	/**
	 * Attribut für den Namen des Bearbeiters in einem Eintrag der
	 * Versionshistorie eines Skripts.
	 */
	public static final String ATL_HISTORIE_ATT_NAME = "Name";

	/**
	 * Attribut für den Grund der Bearbeitung in einem Eintrag der
	 * Versionshistorie eines Skripts.
	 */
	public static final String ATL_HISTORIE_ATT_GRUND = "Grund";

	/**
	 * Attribut für den Quelltext eines Skripts.
	 */
	public static final String SKRIPT_ATT_QUELLTEXT = "Quelltext";

	/**
	 * Attribut für den Namen des Benutzers für die Anmeldung eines Skriptlaufs
	 * beim Datenverteiler.
	 */
	public static final String LAUF_ATT_BENUTZER = "Benutzer";

	/**
	 * Attribut für die Beschreibung eines Skriptlaufs.
	 */
	public static final String LAUF_ATT_BESCHREIBUNG = "Beschreibung";

	/**
	 * Attribut für den Name eines Skriptlaufs.
	 */
	public static final String LAUF_ATT_NAME = "Name";

	/**
	 * Attribut für die Skript-Startparameter eines Skriptlaufs.
	 */
	public static final String LAUF_ATT_PARAMETER = "Parameter";

	/**
	 * Attribut für das Passwort des Benutzers für die Anmeldung eines
	 * Skriptlaufs beim Datenverteiler.
	 */
	public static final String LAUF_ATT_PASSWORT = "Passwort";

	/**
	 * Attribut für die Liste der Protokolleinträge eines Skriptlaufs.
	 */
	public static final String LAUF_ATT_PROTOKOLL = "Protokoll";

	/**
	 * Attribut für das einem Skriptlauf zugeordnete Skript.
	 */
	public static final String LAUF_ATT_SKRIPT = "Skript";

	/**
	 * Attribut für den Starttyp eines Skriptlaufs.
	 */
	public static final String LAUF_ATT_STARTTYP = "Starttyp";

	/**
	 * Attribut für den Startzyklus eines Skriptlaufs.
	 */
	public static final String LAUF_ATT_STARTZYKLUS = "Startzyklus";

	/**
	 * Attribut für den Startzyklus eines Skriptlaufs.
	 */
	public static final String LAUF_ATT_HISTORIE = "Versionshistorie";

	/**
	 * Attribut für den Startzeitpunkt innerhalb eines Startzyklus.
	 */
	public static final String ATL_STARTZYKLUS_ATT_STARTZEITPUNKT = "Startzeitpunkt";

	/**
	 * Attribut für das Intervall innerhalb eines Startzyklus.
	 */
	public static final String ATL_STARTZYKLUS_ATT_INTERVALL = "Intervall";

	/**
	 * Attribut für die Anzahl innerhalb einer Protokolldefinition.
	 */
	public static final String ATL_PROTOKOLL_ATT_ANZAHL = "Anzahl";

	/**
	 * Attribut für die maximale Größe innerhalb einer Protokolldefinition.
	 */
	public static final String ATL_PROTOKOLL_ATT_MAXGROESSE = "MaxGroesse";

	/**
	 * Attribut für den Namen einer Protokolldefinition.
	 */
	public static final String ATL_PROTOKOLL_ATT_NAME = "Name";

	/**
	 * Attribut für den Typ einer Protokolldefinition.
	 */
	public static final String ATL_PROTOKOLL_ATT_TYP = "Typ";

	/**
	 * Attribut für den Namen eines Parameters in einem Skriptparameter.
	 */
	public static final String ATL_PARAMETER_ATT_NAME = "Name";

	/**
	 * Attribut für den Wert eines Parameters in einem Skriptparameter.
	 */
	public static final String ATL_PARAMETER_ATT_WERT = "Wert";

	/** privater Konstruktor für Utility-Klasse. */
	private UDA() {
		super();
	}

}
