/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.verwaltung;

import java.util.ArrayList;
import java.util.Collection;

import de.bsvrz.dav.daf.main.OneSubscriptionPerSendData;
import de.bsvrz.dav.daf.main.config.ConfigurationObject;
import de.bsvrz.dav.daf.main.config.DataModel;
import de.bsvrz.dav.daf.main.config.SystemObject;
import de.bsvrz.dav.daf.main.config.SystemObjectType;
import de.bsvrz.ibv.uda.uda.UmfassendeDatenanalyse;
import de.bsvrz.ibv.uda.uda.data.UDA;
import de.bsvrz.sys.funclib.debug.Debug;

/**
 * die Realisierung des Verwaltungsmoduls der "Umfassenden Datenanalyse".
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public class UdaVerwaltung {

	/**
	 * die Liste der Uda-Module, die verwaltet werden.
	 */
	private final Collection<ServerUdaModul> moduls = new ArrayList<>();

	/**
	 * Konstruktor.
	 *
	 * @param uda
	 *            die Anwendung "Umfassende Datenanalyse"
	 * @param pids
	 *            die Liste der PIDs für UdaModule
	 * @throws UdaServerException
	 *             das Verwaltungsmodul konnte nicht initialisiert werden
	 */
	public UdaVerwaltung(final UmfassendeDatenanalyse uda, final Collection<String> pids) throws UdaServerException {

		Debug.getLogger().info("Uda-Verwaltungsmodul gestartet");

		final DataModel model = uda.getVerbindung().getDataModel();
		final SystemObjectType type = model.getType(UDA.TYP_MODUL);

		for (final String pid : pids) {
			final SystemObject obj = model.getObject(pid);
			if ((obj != null) && obj.isOfType(type)) {
				try {
					moduls.add(new ServerUdaModul(uda, (ConfigurationObject) obj));
				} catch (final OneSubscriptionPerSendData e) {
					throw new UdaServerException("Fehler beim Initialisieren des Verwaltungsmoduls",
							e);
				}
			}
		}
	}

	/**
	 * liefert die Liste der verwalteten Uda-Module.
	 *
	 * @return die Liste der Module
	 */
	public Collection<ServerUdaModul> getModuls() {
		return moduls;
	}
}
